import { GridPro, GridProRendererTypes, foundationGridProShadowOptions, defaultGridProConfig as foundationConfig, } from '@genesislcap/grid-pro';
import { ZeroAgActionRenderer, ZeroAgActionsMenuRenderer, ZeroBooleanRenderer, } from './cell-renderers';
import { zeroGridProStyles as styles } from './grid-pro.styles';
import { zeroGridProTemplate as template } from './grid-pro.template';
import { themeGenesisRapid, themeGenesisRapidDark } from './themes';
const defaultAgHeight = 32;
const defaultRapidTheme = 'ag-theme-genesis-rapid-dark';
/**
 * @tagname %%prefix%%-grid-pro
 */
export class ZeroGridPro extends GridPro {
    constructor() {
        super(...arguments);
        /**
         * Sets default theme to Rapid
         * @override
         */
        this.theme = defaultRapidTheme;
    }
    themeChanged(oldValue, newValue) {
        if (!oldValue && newValue !== defaultRapidTheme)
            return;
        super.themeChanged(oldValue, newValue);
    }
    /**
     * Handles extra ZERO configs
     * @override
     */
    set gridOptions(options) {
        options.components = {
            [GridProRendererTypes.action]: ZeroAgActionRenderer,
            [GridProRendererTypes.actionsMenu]: ZeroAgActionsMenuRenderer,
            [GridProRendererTypes.boolean]: ZeroBooleanRenderer,
        };
        const isRapidTheme = this.theme === themeGenesisRapid || this.theme === themeGenesisRapidDark;
        if (isRapidTheme) {
            this.headerHeight = options.headerHeight ?? defaultAgHeight;
            this.rowHeight = options.rowHeight ?? defaultAgHeight;
        }
        super.gridOptions = options;
    }
}
// explicitly declaring for extensibility
export const zeroGridProShadowOptions = foundationGridProShadowOptions;
export const zeroDefaultGridProConfig = foundationConfig;
export const zeroGridPro = ZeroGridPro.compose({
    baseName: 'grid-pro',
    template,
    styles,
    shadowOptions: zeroGridProShadowOptions,
    ...zeroDefaultGridProConfig,
});
